@@ -380,6 +380,11 @@ class union_map:
                 arg0 = union_map(arg0)
         except:
             raise
+        try:
+            if not arg1.__class__ is stat (isl_map *, void *):
+                arg1 = stat (isl_map *, void *)(arg1)
+        except:
+            raise
         exc_info = [None]
         fn = CFUNCTYPE(c_int, c_void_p, c_void_p)
         def cb_func(cb_arg0, cb_arg1):
@@ -454,6 +459,108 @@ class map(union_map):
         return res
     def __repr__(self):
         return 'isl.map("%s")' % str(self)
+    def lexmin(arg0):
+        try:
+            if not arg0.__class__ is map:
+                arg0 = map(arg0)
+        except:
+            raise
+        res = isl.isl_map_lexmin(isl.isl_map_copy(arg0.ptr))
+        return map(ctx=arg0.ctx, ptr=res)
+    def lexmax(arg0):
+        try:
+            if not arg0.__class__ is map:
+                arg0 = map(arg0)
+        except:
+            raise
+        res = isl.isl_map_lexmax(isl.isl_map_copy(arg0.ptr))
+        return map(ctx=arg0.ctx, ptr=res)
+    def reverse(arg0):
+        try:
+            if not arg0.__class__ is map:
+                arg0 = map(arg0)
+        except:
+            raise
+        res = isl.isl_map_reverse(isl.isl_map_copy(arg0.ptr))
+        return map(ctx=arg0.ctx, ptr=res)
+    def union(arg0, arg1):
+        try:
+            if not arg0.__class__ is map:
+                arg0 = map(arg0)
+        except:
+            raise
+        try:
+            if not arg1.__class__ is map:
+                arg1 = map(arg1)
+        except:
+            return union_map(arg0).union(arg1)
+        res = isl.isl_map_union(isl.isl_map_copy(arg0.ptr), isl.isl_map_copy(arg1.ptr))
+        return map(ctx=arg0.ctx, ptr=res)
+    def intersect_domain(arg0, arg1):
+        try:
+            if not arg0.__class__ is map:
+                arg0 = map(arg0)
+        except:
+            raise
+        try:
+            if not arg1.__class__ is set:
+                arg1 = set(arg1)
+        except:
+            return union_map(arg0).intersect_domain(arg1)
+        res = isl.isl_map_intersect_domain(isl.isl_map_copy(arg0.ptr), isl.isl_set_copy(arg1.ptr))
+        return map(ctx=arg0.ctx, ptr=res)
+    def intersect_range(arg0, arg1):
+        try:
+            if not arg0.__class__ is map:
+                arg0 = map(arg0)
+        except:
+            raise
+        try:
+            if not arg1.__class__ is set:
+                arg1 = set(arg1)
+        except:
+            return union_map(arg0).intersect_range(arg1)
+        res = isl.isl_map_intersect_range(isl.isl_map_copy(arg0.ptr), isl.isl_set_copy(arg1.ptr))
+        return map(ctx=arg0.ctx, ptr=res)
+    def apply_domain(arg0, arg1):
+        try:
+            if not arg0.__class__ is map:
+                arg0 = map(arg0)
+        except:
+            raise
+        try:
+            if not arg1.__class__ is map:
+                arg1 = map(arg1)
+        except:
+            return union_map(arg0).apply_domain(arg1)
+        res = isl.isl_map_apply_domain(isl.isl_map_copy(arg0.ptr), isl.isl_map_copy(arg1.ptr))
+        return map(ctx=arg0.ctx, ptr=res)
+    def apply_range(arg0, arg1):
+        try:
+            if not arg0.__class__ is map:
+                arg0 = map(arg0)
+        except:
+            raise
+        try:
+            if not arg1.__class__ is map:
+                arg1 = map(arg1)
+        except:
+            return union_map(arg0).apply_range(arg1)
+        res = isl.isl_map_apply_range(isl.isl_map_copy(arg0.ptr), isl.isl_map_copy(arg1.ptr))
+        return map(ctx=arg0.ctx, ptr=res)
+    def intersect(arg0, arg1):
+        try:
+            if not arg0.__class__ is map:
+                arg0 = map(arg0)
+        except:
+            raise
+        try:
+            if not arg1.__class__ is map:
+                arg1 = map(arg1)
+        except:
+            return union_map(arg0).intersect(arg1)
+        res = isl.isl_map_intersect(isl.isl_map_copy(arg0.ptr), isl.isl_map_copy(arg1.ptr))
+        return map(ctx=arg0.ctx, ptr=res)
     def intersect_params(arg0, arg1):
         try:
             if not arg0.__class__ is map:
@@ -636,108 +743,6 @@ class map(union_map):
             raise
         res = isl.isl_map_is_bijective(arg0.ptr)
         return res
-    def lexmin(arg0):
-        try:
-            if not arg0.__class__ is map:
-                arg0 = map(arg0)
-        except:
-            raise
-        res = isl.isl_map_lexmin(isl.isl_map_copy(arg0.ptr))
-        return map(ctx=arg0.ctx, ptr=res)
-    def lexmax(arg0):
-        try:
-            if not arg0.__class__ is map:
-                arg0 = map(arg0)
-        except:
-            raise
-        res = isl.isl_map_lexmax(isl.isl_map_copy(arg0.ptr))
-        return map(ctx=arg0.ctx, ptr=res)
-    def reverse(arg0):
-        try:
-            if not arg0.__class__ is map:
-                arg0 = map(arg0)
-        except:
-            raise
-        res = isl.isl_map_reverse(isl.isl_map_copy(arg0.ptr))
-        return map(ctx=arg0.ctx, ptr=res)
-    def union(arg0, arg1):
-        try:
-            if not arg0.__class__ is map:
-                arg0 = map(arg0)
-        except:
-            raise
-        try:
-            if not arg1.__class__ is map:
-                arg1 = map(arg1)
-        except:
-            return union_map(arg0).union(arg1)
-        res = isl.isl_map_union(isl.isl_map_copy(arg0.ptr), isl.isl_map_copy(arg1.ptr))
-        return map(ctx=arg0.ctx, ptr=res)
-    def intersect_domain(arg0, arg1):
-        try:
-            if not arg0.__class__ is map:
-                arg0 = map(arg0)
-        except:
-            raise
-        try:
-            if not arg1.__class__ is set:
-                arg1 = set(arg1)
-        except:
-            return union_map(arg0).intersect_domain(arg1)
-        res = isl.isl_map_intersect_domain(isl.isl_map_copy(arg0.ptr), isl.isl_set_copy(arg1.ptr))
-        return map(ctx=arg0.ctx, ptr=res)
-    def intersect_range(arg0, arg1):
-        try:
-            if not arg0.__class__ is map:
-                arg0 = map(arg0)
-        except:
-            raise
-        try:
-            if not arg1.__class__ is set:
-                arg1 = set(arg1)
-        except:
-            return union_map(arg0).intersect_range(arg1)
-        res = isl.isl_map_intersect_range(isl.isl_map_copy(arg0.ptr), isl.isl_set_copy(arg1.ptr))
-        return map(ctx=arg0.ctx, ptr=res)
-    def apply_domain(arg0, arg1):
-        try:
-            if not arg0.__class__ is map:
-                arg0 = map(arg0)
-        except:
-            raise
-        try:
-            if not arg1.__class__ is map:
-                arg1 = map(arg1)
-        except:
-            return union_map(arg0).apply_domain(arg1)
-        res = isl.isl_map_apply_domain(isl.isl_map_copy(arg0.ptr), isl.isl_map_copy(arg1.ptr))
-        return map(ctx=arg0.ctx, ptr=res)
-    def apply_range(arg0, arg1):
-        try:
-            if not arg0.__class__ is map:
-                arg0 = map(arg0)
-        except:
-            raise
-        try:
-            if not arg1.__class__ is map:
-                arg1 = map(arg1)
-        except:
-            return union_map(arg0).apply_range(arg1)
-        res = isl.isl_map_apply_range(isl.isl_map_copy(arg0.ptr), isl.isl_map_copy(arg1.ptr))
-        return map(ctx=arg0.ctx, ptr=res)
-    def intersect(arg0, arg1):
-        try:
-            if not arg0.__class__ is map:
-                arg0 = map(arg0)
-        except:
-            raise
-        try:
-            if not arg1.__class__ is map:
-                arg1 = map(arg1)
-        except:
-            return union_map(arg0).intersect(arg1)
-        res = isl.isl_map_intersect(isl.isl_map_copy(arg0.ptr), isl.isl_map_copy(arg1.ptr))
-        return map(ctx=arg0.ctx, ptr=res)
     def gist(arg0, arg1):
         try:
             if not arg0.__class__ is map:
@@ -778,6 +783,11 @@ class map(union_map):
                 arg0 = map(arg0)
         except:
             raise
+        try:
+            if not arg1.__class__ is stat (isl_basic_map *, void *):
+                arg1 = stat (isl_basic_map *, void *)(arg1)
+        except:
+            return union_map(arg0).foreach_basic_map(arg1)
         exc_info = [None]
         fn = CFUNCTYPE(c_int, c_void_p, c_void_p)
         def cb_func(cb_arg0, cb_arg1):
@@ -799,6 +809,15 @@ isl.isl_map_read_from_str.restype = c_void_p
 isl.isl_map_read_from_str.argtypes = [Context, c_char_p]
 isl.isl_map_from_basic_map.restype = c_void_p
 isl.isl_map_from_basic_map.argtypes = [c_void_p]
+isl.isl_map_lexmin.restype = c_void_p
+isl.isl_map_lexmax.restype = c_void_p
+isl.isl_map_reverse.restype = c_void_p
+isl.isl_map_union.restype = c_void_p
+isl.isl_map_intersect_domain.restype = c_void_p
+isl.isl_map_intersect_range.restype = c_void_p
+isl.isl_map_apply_domain.restype = c_void_p
+isl.isl_map_apply_range.restype = c_void_p
+isl.isl_map_intersect.restype = c_void_p
 isl.isl_map_intersect_params.restype = c_void_p
 isl.isl_map_subtract.restype = c_void_p
 isl.isl_map_complement.restype = c_void_p
@@ -810,15 +829,6 @@ isl.isl_map_flatten.restype = c_void_p
 isl.isl_map_flatten_domain.restype = c_void_p
 isl.isl_map_flatten_range.restype = c_void_p
 isl.isl_map_sample.restype = c_void_p
-isl.isl_map_lexmin.restype = c_void_p
-isl.isl_map_lexmax.restype = c_void_p
-isl.isl_map_reverse.restype = c_void_p
-isl.isl_map_union.restype = c_void_p
-isl.isl_map_intersect_domain.restype = c_void_p
-isl.isl_map_intersect_range.restype = c_void_p
-isl.isl_map_apply_domain.restype = c_void_p
-isl.isl_map_apply_range.restype = c_void_p
-isl.isl_map_intersect.restype = c_void_p
 isl.isl_map_gist.restype = c_void_p
 isl.isl_map_gist_domain.restype = c_void_p
 isl.isl_map_coalesce.restype = c_void_p
@@ -847,54 +857,6 @@ class basic_map(map):
         return res
     def __repr__(self):
         return 'isl.basic_map("%s")' % str(self)
-    def deltas(arg0):
-        try:
-            if not arg0.__class__ is basic_map:
-                arg0 = basic_map(arg0)
-        except:
-            raise
-        res = isl.isl_basic_map_deltas(isl.isl_basic_map_copy(arg0.ptr))
-        return basic_set(ctx=arg0.ctx, ptr=res)
-    def flatten(arg0):
-        try:
-            if not arg0.__class__ is basic_map:
-                arg0 = basic_map(arg0)
-        except:
-            raise
-        res = isl.isl_basic_map_flatten(isl.isl_basic_map_copy(arg0.ptr))
-        return basic_map(ctx=arg0.ctx, ptr=res)
-    def flatten_domain(arg0):
-        try:
-            if not arg0.__class__ is basic_map:
-                arg0 = basic_map(arg0)
-        except:
-            raise
-        res = isl.isl_basic_map_flatten_domain(isl.isl_basic_map_copy(arg0.ptr))
-        return basic_map(ctx=arg0.ctx, ptr=res)
-    def flatten_range(arg0):
-        try:
-            if not arg0.__class__ is basic_map:
-                arg0 = basic_map(arg0)
-        except:
-            raise
-        res = isl.isl_basic_map_flatten_range(isl.isl_basic_map_copy(arg0.ptr))
-        return basic_map(ctx=arg0.ctx, ptr=res)
-    def sample(arg0):
-        try:
-            if not arg0.__class__ is basic_map:
-                arg0 = basic_map(arg0)
-        except:
-            raise
-        res = isl.isl_basic_map_sample(isl.isl_basic_map_copy(arg0.ptr))
-        return basic_map(ctx=arg0.ctx, ptr=res)
-    def detect_equalities(arg0):
-        try:
-            if not arg0.__class__ is basic_map:
-                arg0 = basic_map(arg0)
-        except:
-            raise
-        res = isl.isl_basic_map_detect_equalities(isl.isl_basic_map_copy(arg0.ptr))
-        return basic_map(ctx=arg0.ctx, ptr=res)
     def intersect_domain(arg0, arg1):
         try:
             if not arg0.__class__ is basic_map:
@@ -989,6 +951,22 @@ class basic_map(map):
             raise
         res = isl.isl_basic_map_reverse(isl.isl_basic_map_copy(arg0.ptr))
         return basic_map(ctx=arg0.ctx, ptr=res)
+    def sample(arg0):
+        try:
+            if not arg0.__class__ is basic_map:
+                arg0 = basic_map(arg0)
+        except:
+            raise
+        res = isl.isl_basic_map_sample(isl.isl_basic_map_copy(arg0.ptr))
+        return basic_map(ctx=arg0.ctx, ptr=res)
+    def detect_equalities(arg0):
+        try:
+            if not arg0.__class__ is basic_map:
+                arg0 = basic_map(arg0)
+        except:
+            raise
+        res = isl.isl_basic_map_detect_equalities(isl.isl_basic_map_copy(arg0.ptr))
+        return basic_map(ctx=arg0.ctx, ptr=res)
     def is_equal(arg0, arg1):
         try:
             if not arg0.__class__ is basic_map:
@@ -1039,6 +1017,38 @@ class basic_map(map):
             return map(arg0).is_subset(arg1)
         res = isl.isl_basic_map_is_subset(arg0.ptr, arg1.ptr)
         return res
+    def deltas(arg0):
+        try:
+            if not arg0.__class__ is basic_map:
+                arg0 = basic_map(arg0)
+        except:
+            raise
+        res = isl.isl_basic_map_deltas(isl.isl_basic_map_copy(arg0.ptr))
+        return basic_set(ctx=arg0.ctx, ptr=res)
+    def flatten(arg0):
+        try:
+            if not arg0.__class__ is basic_map:
+                arg0 = basic_map(arg0)
+        except:
+            raise
+        res = isl.isl_basic_map_flatten(isl.isl_basic_map_copy(arg0.ptr))
+        return basic_map(ctx=arg0.ctx, ptr=res)
+    def flatten_domain(arg0):
+        try:
+            if not arg0.__class__ is basic_map:
+                arg0 = basic_map(arg0)
+        except:
+            raise
+        res = isl.isl_basic_map_flatten_domain(isl.isl_basic_map_copy(arg0.ptr))
+        return basic_map(ctx=arg0.ctx, ptr=res)
+    def flatten_range(arg0):
+        try:
+            if not arg0.__class__ is basic_map:
+                arg0 = basic_map(arg0)
+        except:
+            raise
+        res = isl.isl_basic_map_flatten_range(isl.isl_basic_map_copy(arg0.ptr))
+        return basic_map(ctx=arg0.ctx, ptr=res)
     def gist(arg0, arg1):
         try:
             if not arg0.__class__ is basic_map:
@@ -1055,12 +1065,6 @@ class basic_map(map):
 
 isl.isl_basic_map_read_from_str.restype = c_void_p
 isl.isl_basic_map_read_from_str.argtypes = [Context, c_char_p]
-isl.isl_basic_map_deltas.restype = c_void_p
-isl.isl_basic_map_flatten.restype = c_void_p
-isl.isl_basic_map_flatten_domain.restype = c_void_p
-isl.isl_basic_map_flatten_range.restype = c_void_p
-isl.isl_basic_map_sample.restype = c_void_p
-isl.isl_basic_map_detect_equalities.restype = c_void_p
 isl.isl_basic_map_intersect_domain.restype = c_void_p
 isl.isl_basic_map_intersect_range.restype = c_void_p
 isl.isl_basic_map_intersect.restype = c_void_p
@@ -1069,8 +1073,14 @@ isl.isl_basic_map_apply_domain.restype = c_void_p
 isl.isl_basic_map_apply_range.restype = c_void_p
 isl.isl_basic_map_affine_hull.restype = c_void_p
 isl.isl_basic_map_reverse.restype = c_void_p
+isl.isl_basic_map_sample.restype = c_void_p
+isl.isl_basic_map_detect_equalities.restype = c_void_p
 isl.isl_basic_map_lexmin.restype = c_void_p
 isl.isl_basic_map_lexmax.restype = c_void_p
+isl.isl_basic_map_deltas.restype = c_void_p
+isl.isl_basic_map_flatten.restype = c_void_p
+isl.isl_basic_map_flatten_domain.restype = c_void_p
+isl.isl_basic_map_flatten_range.restype = c_void_p
 isl.isl_basic_map_gist.restype = c_void_p
 isl.isl_basic_map_free.argtypes = [c_void_p]
 isl.isl_basic_map_to_str.argtypes = [c_void_p]
@@ -1292,6 +1302,11 @@ class union_set:
                 arg0 = union_set(arg0)
         except:
             raise
+        try:
+            if not arg1.__class__ is stat (isl_set *, void *):
+                arg1 = stat (isl_set *, void *)(arg1)
+        except:
+            raise
         exc_info = [None]
         fn = CFUNCTYPE(c_int, c_void_p, c_void_p)
         def cb_func(cb_arg0, cb_arg1):
@@ -1357,30 +1372,6 @@ class set(union_set):
         return res
     def __repr__(self):
         return 'isl.set("%s")' % str(self)
-    def identity(arg0):
-        try:
-            if not arg0.__class__ is set:
-                arg0 = set(arg0)
-        except:
-            raise
-        res = isl.isl_set_identity(isl.isl_set_copy(arg0.ptr))
-        return map(ctx=arg0.ctx, ptr=res)
-    def is_wrapping(arg0):
-        try:
-            if not arg0.__class__ is set:
-                arg0 = set(arg0)
-        except:
-            raise
-        res = isl.isl_set_is_wrapping(arg0.ptr)
-        return res
-    def flatten(arg0):
-        try:
-            if not arg0.__class__ is set:
-                arg0 = set(arg0)
-        except:
-            raise
-        res = isl.isl_set_flatten(isl.isl_set_copy(arg0.ptr))
-        return set(ctx=arg0.ctx, ptr=res)
     def lexmin(arg0):
         try:
             if not arg0.__class__ is set:
@@ -1589,6 +1580,11 @@ class set(union_set):
                 arg0 = set(arg0)
         except:
             raise
+        try:
+            if not arg1.__class__ is stat (isl_basic_set *, void *):
+                arg1 = stat (isl_basic_set *, void *)(arg1)
+        except:
+            return union_set(arg0).foreach_basic_set(arg1)
         exc_info = [None]
         fn = CFUNCTYPE(c_int, c_void_p, c_void_p)
         def cb_func(cb_arg0, cb_arg1):
@@ -1605,13 +1601,35 @@ class set(union_set):
         if exc_info[0] != None:
             raise exc_info[0][0], exc_info[0][1], exc_info[0][2]
         return res
+    def identity(arg0):
+        try:
+            if not arg0.__class__ is set:
+                arg0 = set(arg0)
+        except:
+            raise
+        res = isl.isl_set_identity(isl.isl_set_copy(arg0.ptr))
+        return map(ctx=arg0.ctx, ptr=res)
+    def is_wrapping(arg0):
+        try:
+            if not arg0.__class__ is set:
+                arg0 = set(arg0)
+        except:
+            raise
+        res = isl.isl_set_is_wrapping(arg0.ptr)
+        return res
+    def flatten(arg0):
+        try:
+            if not arg0.__class__ is set:
+                arg0 = set(arg0)
+        except:
+            raise
+        res = isl.isl_set_flatten(isl.isl_set_copy(arg0.ptr))
+        return set(ctx=arg0.ctx, ptr=res)
 
 isl.isl_set_read_from_str.restype = c_void_p
 isl.isl_set_read_from_str.argtypes = [Context, c_char_p]
 isl.isl_set_from_basic_set.restype = c_void_p
 isl.isl_set_from_basic_set.argtypes = [c_void_p]
-isl.isl_set_identity.restype = c_void_p
-isl.isl_set_flatten.restype = c_void_p
 isl.isl_set_lexmin.restype = c_void_p
 isl.isl_set_lexmax.restype = c_void_p
 isl.isl_set_sample.restype = c_void_p
@@ -1626,6 +1644,8 @@ isl.isl_set_complement.restype = c_void_p
 isl.isl_set_apply.restype = c_void_p
 isl.isl_set_gist.restype = c_void_p
 isl.isl_set_coalesce.restype = c_void_p
+isl.isl_set_identity.restype = c_void_p
+isl.isl_set_flatten.restype = c_void_p
 isl.isl_set_free.argtypes = [c_void_p]
 isl.isl_set_to_str.argtypes = [c_void_p]
 isl.isl_set_to_str.restype = POINTER(c_char)
@@ -1651,22 +1671,6 @@ class basic_set(set):
         return res
     def __repr__(self):
         return 'isl.basic_set("%s")' % str(self)
-    def is_wrapping(arg0):
-        try:
-            if not arg0.__class__ is basic_set:
-                arg0 = basic_set(arg0)
-        except:
-            raise
-        res = isl.isl_basic_set_is_wrapping(arg0.ptr)
-        return res
-    def flatten(arg0):
-        try:
-            if not arg0.__class__ is basic_set:
-                arg0 = basic_set(arg0)
-        except:
-            raise
-        res = isl.isl_basic_set_flatten(isl.isl_basic_set_copy(arg0.ptr))
-        return basic_set(ctx=arg0.ctx, ptr=res)
     def intersect(arg0, arg1):
         try:
             if not arg0.__class__ is basic_set:
@@ -1731,6 +1735,16 @@ class basic_set(set):
         res = isl.isl_basic_set_detect_equalities(isl.isl_basic_set_copy(arg0.ptr))
         return basic_set(ctx=arg0.ctx, ptr=res)
     def is_equal(arg0, arg1):
+        try:
+            if not arg0.__class__ is basic_set:
+                arg0 = basic_set(arg0)
+        except:
+            raise
+        try:
+            if not arg1.__class__ is basic_set:
+                arg1 = basic_set(arg1)
+        except:
+            return set(arg0).is_equal(arg1)
         res = isl.isl_basic_set_is_equal(arg0.ptr, arg1.ptr)
         return res
     def lexmin(arg0):
@@ -1796,10 +1810,25 @@ class basic_set(set):
             return set(arg0).gist(arg1)
         res = isl.isl_basic_set_gist(isl.isl_basic_set_copy(arg0.ptr), isl.isl_basic_set_copy(arg1.ptr))
         return basic_set(ctx=arg0.ctx, ptr=res)
+    def is_wrapping(arg0):
+        try:
+            if not arg0.__class__ is basic_set:
+                arg0 = basic_set(arg0)
+        except:
+            raise
+        res = isl.isl_basic_set_is_wrapping(arg0.ptr)
+        return res
+    def flatten(arg0):
+        try:
+            if not arg0.__class__ is basic_set:
+                arg0 = basic_set(arg0)
+        except:
+            raise
+        res = isl.isl_basic_set_flatten(isl.isl_basic_set_copy(arg0.ptr))
+        return basic_set(ctx=arg0.ctx, ptr=res)
 
 isl.isl_basic_set_read_from_str.restype = c_void_p
 isl.isl_basic_set_read_from_str.argtypes = [Context, c_char_p]
-isl.isl_basic_set_flatten.restype = c_void_p
 isl.isl_basic_set_intersect.restype = c_void_p
 isl.isl_basic_set_intersect_params.restype = c_void_p
 isl.isl_basic_set_apply.restype = c_void_p
@@ -1810,50 +1839,7 @@ isl.isl_basic_set_lexmin.restype = c_void_p
 isl.isl_basic_set_lexmax.restype = c_void_p
 isl.isl_basic_set_union.restype = c_void_p
 isl.isl_basic_set_gist.restype = c_void_p
+isl.isl_basic_set_flatten.restype = c_void_p
 isl.isl_basic_set_free.argtypes = [c_void_p]
 isl.isl_basic_set_to_str.argtypes = [c_void_p]
 isl.isl_basic_set_to_str.restype = POINTER(c_char)
-
-class pw_qpolynomial:
-    def __init__(self, *args, **keywords):
-        if "ptr" in keywords:
-            self.ctx = keywords["ctx"]
-            self.ptr = keywords["ptr"]
-            return
-        raise Error
-    def __del__(self):
-        if hasattr(self, 'ptr'):
-            isl.isl_pw_qpolynomial_free(self.ptr)
-    def __str__(self):
-        ptr = isl.isl_pw_qpolynomial_to_str(self.ptr)
-        res = str(cast(ptr, c_char_p).value)
-        libc.free(ptr)
-        return res
-    def __repr__(self):
-        return 'isl.pw_qpolynomial("%s")' % str(self)
-
-isl.isl_pw_qpolynomial_free.argtypes = [c_void_p]
-isl.isl_pw_qpolynomial_to_str.argtypes = [c_void_p]
-isl.isl_pw_qpolynomial_to_str.restype = POINTER(c_char)
-
-class union_pw_qpolynomial:
-    def __init__(self, *args, **keywords):
-        if "ptr" in keywords:
-            self.ctx = keywords["ctx"]
-            self.ptr = keywords["ptr"]
-            return
-        raise Error
-    def __del__(self):
-        if hasattr(self, 'ptr'):
-            isl.isl_union_pw_qpolynomial_free(self.ptr)
-    def __str__(self):
-        ptr = isl.isl_union_pw_qpolynomial_to_str(self.ptr)
-        res = str(cast(ptr, c_char_p).value)
-        libc.free(ptr)
-        return res
-    def __repr__(self):
-        return 'isl.union_pw_qpolynomial("%s")' % str(self)
-
-isl.isl_union_pw_qpolynomial_free.argtypes = [c_void_p]
-isl.isl_union_pw_qpolynomial_to_str.argtypes = [c_void_p]
-isl.isl_union_pw_qpolynomial_to_str.restype = POINTER(c_char)
